package com.srs.teacher.mapper;

import java.util.List;

import com.srs.teacher.domain.SysTeacherCourse;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * courseMapper接口
 *
 * @author srs
 * @date 2024-06-05
 */
public interface SysTeacherCourseMapper extends BaseMapper<SysTeacherCourse> {
    /**
     * 查询course
     *
     * @param courseId course主键
     * @return course
     */
    public SysTeacherCourse selectSysTeacherCourseByCourseId(Long courseId);

    /**
     * 查询course列表
     *
     * @param sysTeacherCourse course
     * @return course集合
     */
    List<SysTeacherCourse> selectSysTeacherCourseList(SysTeacherCourse sysTeacherCourse);

    /**
     * 新增course
     *
     * @param sysTeacherCourse course
     * @return 结果
     */
    int insertSysTeacherCourse(SysTeacherCourse sysTeacherCourse);

    /**
     * 修改course
     *
     * @param sysTeacherCourse course
     * @return 结果
     */
    int updateSysTeacherCourse(SysTeacherCourse sysTeacherCourse);

    /**
     * 删除course
     *
     * @param courseId course主键
     * @return 结果
     */
    int deleteSysTeacherCourseByCourseId(Long courseId);

    /**
     * 批量删除course
     *
     * @param courseIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSysTeacherCourseByCourseIds(Long[] courseIds);
}
